@@ -6,7 +6,7 @@
 ;; Maintainer: S. Irie
 ;; Keywords: Input Method, i18n
 
-(defconst scim-bridge-ja-version "0.8.0")
+(defconst scim-bridge-ja-version "0.8.1")
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -29,13 +29,18 @@
 ;; ヨーロッパ言語) をサポートする POSIX スタイルのオペレーティングシステム
 ;; (Linux や BSD) のためのインプットメソッド (IM) プラットフォームです。
 
-;; scim-brifge.el はEmacs のための SCIM-Bridge クライアントです。
-;; ただし、これは公式の SCIM-Bridge の一部ではありません。
+;; scim-brifge.el はEmacs のための SCIM-Bridge クライアントであり、 SCIM
+;; を 用いた on the spot スタイルの入力を可能とするものです。入力状態は
+;; 個々のバッファについて保持され、また SCIM がアクティブな状態でも C-x や
+;; C-c 等のプレフィックスキーを使うことができます。したがって、ユーザーは
+;; このプログラムを用いて様々な言語を速く、快適に入力することができます。
 
 ;; このプログラムをロードすることによって、 scim-bridge.el で定義される変数
 ;; および関数の説明文字列が日本語で書かれたものに差し替えられ、また日本語入力
 ;; のためのいくつかの便利なコマンドが使用できるようになります。
 
+;; このプログラムは SCIM-Bridge の一部ではありません。
+
 ;;
 ;; Installation:
 ;;
@@ -45,14 +50,15 @@
 ;; 以下の行を .emacs ファイルに追加します。
 ;;
 ;;   (require 'scim-bridge-ja)
+;;   (add-hook 'after-init-hook 'scim-mode-on)
 ;;
-;; Emacs を起動するときは、コマンドラインから以下のように打ち込んで下さい。
+;; EmacsでXIMを無効にするために、~/.Xresources ファイルに
 ;;
-;;   XMODIFIERS=@im=none emacs
+;;   Emacs*useXIM: false
 ;;
-;; 起動したら、scim-mode を ON にします。
+;; を追加し、Xセッションを再スタートするか、以下のシェルコマンドを実行します。
 ;;
-;;   M-x scim-mode
+;;   xrdb ~/.Xresources
 ;;
 ;;
 ;; .emacs ファイルの設定例です。
@@ -83,6 +89,10 @@
 ;;
 
 ;; History:
+;; 2010-05-29  S. Irie
+;;         * Add/modify translations
+;;         * Version 0.8.1
+;;
 ;; 2010-04-23  S. Irie
 ;;         * Add/modify/delete translations
 ;;         * Version 0.8.0
@@ -312,7 +322,7 @@ SCIM-Anthy の設定における「同時打鍵時間」に相当する時間間
 ます。値が整数の 0 であると、このオプションは不活性となり、カーソル形状は変え
 られません。。
 `cursor-type' をご覧下さい。"
- '(choice (const :tag "標準（0）" 0)
+ '(choice (const :tag "指定しない（0）" 0)
 	  (const :tag "フレームのパラメータを使用" t)
 	  (const :tag "表示しない" nil)
 	  (const :tag "塗りつぶされた箱型" box)
@@ -332,7 +342,7 @@ SCIM-Anthy の設定における「同時打鍵時間」に相当する時間間
 るカーソル形状を指定します。値が整数の 0 であると、このオプションは不活性と
 なり、カーソル形状は変えられません。
 `cursor-type' をご覧下さい。"
- '(choice (const :tag "標準（0）" 0)
+ '(choice (const :tag "指定しない（0）" 0)
 	  (const :tag "フレームのパラメータを使用" t)
 	  (const :tag "表示しない" nil)
 	  (const :tag "塗りつぶされた箱型" box)
@@ -456,6 +466,11 @@ SCIM がオフの時、あるいは入力フォーカスが他のアプリケー
  'scim-tmp-buffer-name
  "エージェントと通信するためのワーキングバッファの名前です。")
 
+(scim-set-variable-doc
+ 'scim-incompatible-major-modes
+ "scim-mode のキーマップが無効化されるメジャーモードを指定するシンボルの
+リストです。")
+
 (scim-set-variable-doc
  'scim-incompatible-mode-hooks
  "メジャーモードフックを指定するシンボルのリストです。これらのフックが
